pub fn generate(check: bool, package: bool)Expand description
Generates GitHub Actions workflow files based on the provided flags.
- check -> workflows/check.yml
- package -> workflows/release.yml
Exits with code 1 if a target file already exists or any IO error occurs.